@@ -19,4 +19,9 @@ class media(object):
 			changed_image : bytes = BytesIO()
 			im.save(changed_image , format='PNG')
 			changed_image : bytes = changed_image.getvalue()
-		return b64encode(changed_image)
\ No newline at end of file
+		return b64encode(changed_image)
+
+	def getImageSize(self , image_bytes : bytes) -> tuple:
+		im = Image.open(BytesIO(image_bytes))
+		[width , height] = im.size
+		return [width , height]
\ No newline at end of file
